summaryrefslogtreecommitdiffstats
path: root/Modules/FindVTK.cmake
diff options
context:
space:
mode:
authorKen Martin <ken.martin@kitware.com>2001-09-20 14:27:29 (GMT)
committerKen Martin <ken.martin@kitware.com>2001-09-20 14:27:29 (GMT)
commit924cf69ec65d653d47a1cd2da2802b2edca8f2e6 (patch)
tree8fd5dff5fd30f79818b07123204b50aa275d3ebd /Modules/FindVTK.cmake
parenteae77fd08783e9abb251b977536231e0246b0f09 (diff)
downloadCMake-924cf69ec65d653d47a1cd2da2802b2edca8f2e6.zip
CMake-924cf69ec65d653d47a1cd2da2802b2edca8f2e6.tar.gz
CMake-924cf69ec65d653d47a1cd2da2802b2edca8f2e6.tar.bz2
minor changes
Diffstat (limited to 'Modules/FindVTK.cmake')
-rw-r--r--Modules/FindVTK.cmake16
1 files changed, 8 insertions, 8 deletions
diff --git a/Modules/FindVTK.cmake b/Modules/FindVTK.cmake
index bdba013..79715f4 100644
--- a/Modules/FindVTK.cmake
+++ b/Modules/FindVTK.cmake
@@ -3,9 +3,9 @@
#
# This module defines
#
# VTK_INSTALL_PATH - where is the installed version of VTK
# VTK_SOURCE_PATH - where is VTK source code
# VTK_BIN_PATH - where is the binary tree (only defined if SOURCE_PATH is defined)
# USE_INSTALLED_VTK - sould an installed or source version of VTK be used
#
@@ -15,7 +15,7 @@
#
# look in the cmake list of recent source and bin dirs for this user
#
-FIND_PATH(VTK_SOURCE_PATH Common/vtkObject.h
+FIND_PATH(VTK_SOURCE_DIR Common/vtkObject.h
[HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereSource]
[HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereSource2]
[HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereSource3]
@@ -28,12 +28,12 @@ FIND_PATH(VTK_SOURCE_PATH Common/vtkObject.h
#
# If we found a source tree then set use_installed_vtk to 0
#
-IF (VTK_SOURCE_PATH)
+IF (VTK_SOURCE_DIR)
SET (USE_INSTALLED_VTK 0 CACHE BOOL "Is an installed (versus source) version of VTK used")
#
# Look for a binary tree
#
- FIND_PATH(VTK_BIN_PATH vtkConfigure.h
+ FIND_PATH(VTK_BINARY_DIR vtkConfigure.h
[HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereBuild]
[HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereBuild2]
[HKEY_CURRENT_USER\\Software\\Kitware\\CMakeSetup\\Settings\\StartPath;WhereBuild3]
@@ -45,7 +45,7 @@ IF (VTK_SOURCE_PATH)
$ENV{HOME}/VTKBIN
$ENV{HOME}/vtkbin
)
-ELSE (VTK_SOURCE_PATH)
+ELSE (VTK_SOURCE_DIR)
# look for the vtk header files in installed places
FIND_PATH(VTK_INSTALL_PATH include/vtk/vtkObject.h
/usr/local
@@ -57,7 +57,7 @@ ELSE (VTK_SOURCE_PATH)
IF (VTK_INSTALL_PATH)
SET (USE_INSTALLED_VTK 1 CACHE BOOL "Is an installed (versus source) version of VTK used")
ENDIF (VTK_INSTALL_PATH)
-ENDIF (VTK_SOURCE_PATH)
+ENDIF (VTK_SOURCE_DIR)
IF (USE_INSTALLED_VTK)
# look for the vtk header files in installed places
@@ -3,9 +3,9 @@
# This module defines
#
-# VTK_INSTALL_PATH - where is the installed version of VTK
-# VTK_SOURCE_PATH - where is VTK source code
-# VTK_BIN_PATH - where is the binary tree (only defined if SOURCE_PATH is defined)
+# VTK_INSTALL_DIR - where is the installed version of VTK
+# VTK_SOURCE_DIR - where is VTK source code
+# VTK_BINARY_DIR - where is the binary tree (only defined if SOURCE_PATH is defined)
# USE_INSTALLED_VTK - sould an installed or source version of VTK be used
#